#-------------------------------------------------------------------------------
# Name          Dem2Watershed
# Description:  Scripted Watershed Delineation using ArcGIS Hydrology Tools
# Author:       David Tarboton
# Created:      10/24/2016
#-------------------------------------------------------------------------------

import arcpy
from arcpy import env
from arcpy.sa import *

# Set inputs
outDir=r"D:\GISWR\MyWatershed\MyWatershed.gdb"
DEM="dem"
gage = "Basemap/Outlet"
threshold = 10000
snapdistance = 100

# Set workspace environment
env.workspace = outDir
env.scratchWorkspace = outDir
env.overwriteOutput = True

outFill = Fill("dem", None)
outFill.save("fel"); print("DEM Filled")

outFlowDirection = FlowDirection("fel", "NORMAL")
outFlowDirection.save("fdr"); print("Flow directions computed")

outFlowAccumulation = FlowAccumulation("fdr")
outFlowAccumulation.save("fac"); print("Flow accumulation computed")

outSnapPour = SnapPourPoint(gage, "fac", snapdistance)
outSnapPour.save("SnapOutlet"); print("Pour point snapped")

outWatershed = Watershed("fdr", "SnapOutlet")
outWatershed.save("demw"); print("Watershed delineated")

StreamRaster = (Raster("fac") >= threshold) & (Raster("demw") >= 0)
StreamRaster.save("str"); print("Stream raster generated")

outStreamLink = StreamLink("str","fdr")
outStreamLink.save("strlnk"); print("Stream links created")

Catchment = Watershed("fdr", "strlnk")
Catchment.save("CatchmentGrid"); print("Catchment grid created")

StreamToFeature("strlnk", "fdr", "DrainageLine","NO_SIMPLIFY")
arcpy.RasterToPolygon_conversion("CatchmentGrid", "CatchTemp", "NO_SIMPLIFY")
arcpy.Dissolve_management("CatchTemp", "Catchments", "gridcode")
arcpy.Dissolve_management("CatchTemp", "WholeBasin")
print("Vector conversions done")

